@@ -1,5 +1,6 @@
 #!/usr/bin/env python
 import logging
+import os
 import sys
 from os.path import abspath, dirname
 
@@ -14,6 +15,8 @@ base_dir = dirname(abspath(__file__))
 DEFAULT_SETTINGS = DefaultTestSettings(
     APP_NAME="edc_model",
     BASE_DIR=base_dir,
+    ETC_DIR=os.path.join(base_dir, app_name, "tests", "etc"),
+    KEY_PATH=os.path.join(base_dir, app_name, "tests", "etc"),
     ALLOWED_HOSTS=["localhost"],
     ROOT_URLCONF=f"{app_name}.tests.urls",
     STATIC_URL="/static/",
@@ -26,6 +29,7 @@ DEFAULT_SETTINGS = DefaultTestSettings(
         "django.contrib.staticfiles",
         "django.contrib.sites",
         "multisite",
+        "django_crypto_fields.apps.AppConfig",
         "edc_dashboard.apps.AppConfig",
         "edc_device.apps.AppConfig",
         "edc_sites.apps.AppConfig",
